@@ -9,6 +9,7 @@ Created on Mon Oct 21 14:42:57 2019
 """
 import uuid
 import pickle as pkl
+import inspect
 from types import FunctionType
 from typing import (Optional, ByteString, Union, Callable, Dict, Any, List,
                     Tuple)
@@ -22,6 +23,7 @@ import torch
 from torch.optim import Optimizer
 from torch.nn.modules.loss import _Loss
 from torch.nn.utils import clip_grad_norm_
+from torch.nn.parallel.distributed import DistributedDataParallel as DDP
 from torch.cuda.amp import GradScaler
 from torch.utils.data import DataLoader, Dataset
 
@@ -48,6 +50,29 @@ def _setattr(model, attr, value):
     setattr(model, attr_split[0], value)
 
 
+def get_params(model: BaseEstimator):
+    r"""
+    Fonction possédant le
+    """
+    att_ddp = inspect.signature(DDP.__init__)
+    att_mod = inspect.signature(model.__init__)
+    parameters = [
+        pp
+        for pp in att_mod.parameters.values()
+        if pp.name != "self" and pp.kind != pp.VAR_KEYWORD and pp not in att_ddp.parameters.values()
+    ]
+    for pp in parameters:
+        if pp.king == pp.VAR_POSITIONAL:
+            raise RuntimeError(
+                "scikit-learn estimators shoud always "
+                "specify their parameters in the signature "
+                "of thier __init__ (no varargs)."
+                "%s with constructor %s doesn't "
+                "follow this convention." % (model, att_mod)
+            )
+    return sorted([pp.name for pp in parameters])
+
+
 class BaseEnvironnement(BaseEstimator):
     r"""
     Classe d'environnement PyTorch pour être compatible Scikit-Learn.
@@ -168,7 +193,11 @@ class BaseEnvironnement(BaseEstimator):
             path est un chemin ou a Pickles.dump(obj, **kargs_dump) si None.
         """
         # get_params est hérité de BaseEstimator
-        params = self.get_params()
+        mother_classes = self.__class__.__bases__
+        if DDP not in mother_classes:
+            params = self.get_params()
+        else:
+            params = get_params(self)
         state_dict = self.state_dict()
         if save_optimizer_state:
             state_optimizer = self.optimizer.state_dict()
